@@ -116,7 +116,7 @@ class _AiidaLabApp:
             return self._repo.dirty()
 
     def uninstall(self):
-        trash_path = Path.home().joinpath(".trash", f"self.name-{uuid4()!s}")
+        trash_path = Path.home().joinpath(".trash", f"{self.name}-{uuid4()!s}")
         if self.path.exists():
             trash_path.parent.mkdir(parents=True, exist_ok=True)
             self.path.rename(trash_path)
@@ -499,7 +499,7 @@ class AiidaLabApp(traitlets.HasTraits):
         """
         installed_version = self._installed_version()
         if installed_version not in (AppVersion.UNKNOWN, AppVersion.NOT_INSTALLED):
-            available_versions = list(self._available_versions())
+            available_versions = list(self.available_versions)
             if len(available_versions):
                 return self._installed_version() != available_versions[0]
         return False
